%% EasySpin Academy 2020 - Session 3 - Liquid-state EPR
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)
%{
This session works through EasySpin's capabilities for the simulation of EPR
spectra of liquid-state samples. A lot of the experimental settings are also
applicable to slow-motion and to solid-state samples.
%}

% Different functions for different regimes: pepper, chili, garlic

%% DEMONSTRATION 03-01: Simple simulation
clear
Sys.g = 2;
Sys.lwpp = 0.3; % mT
Exp.mwFreq = 9.5; % GHz
garlic(Sys,Exp);

% note that garlic chooses field range automatically

%% EXERCISE 03-01: Simple simulation
%{
Simulate the 9.8 GHz spectrum of the radical DPPH using its g-value of 2.0036 
and a convolutional peak-to-peak line width of 2 G. (Make sure to convert G to
mT: 1 mT = 10 G).
%}
clear
DPPH.g = 2.0036;
DPPH.lwpp = 0.2; % mT
Exp.mwFreq = 9.8; % GHz
garlic(DPPH,Exp);

%% DEMONSTRATION 03-02: Field range and number of points
clear, clc
Sys.g = 2;
Sys.lwpp = 0.3; % mT

Exp.mwFreq = 9.5; % GHz
Exp.Range = [315 355]; % mT
garlic(Sys,Exp);

Exp2.mwFreq = 9.5; % GHz
Exp2.CenterSweep = [339 5]; % mT
garlic(Sys,Exp2);

Exp2.nPoints = 70;
garlic(Sys,Exp2);

% Warning: make sure there are always a few points per line width.
Exp2.nPoints = 25;
garlic(Sys,Exp2); % just one point per linewidth -> error!

%% EXERCISE 03-02: Field range and number of points
%{
Plot the 35 GHz spectrum of DPPH over a field range of 1245 to 1250 mT, using
400 points. Use the zoom to determine the field at the center of the line.
%}
clear
DPPH.g = 2.0036;
DPPH.lwpp = 0.2; % mT
Exp.mwFreq = 35; % GHz
Exp.Range = [1245 1250]; % mT
Exp.nPoints = 400;
garlic(DPPH,Exp);

% ask garlic to return field axis and spectrum
[B,spc] = garlic(DPPH,Exp);
plot(B,spc);

%% DEMONSTRATION 03-03: convolutional line broadenings (Sys.lwpp, Sys.lw; Gaussian vs. Lorentzian)
clear
Sys.g = 2;
Sys.lwpp = 1; % mT
Exp.mwFreq = 9.5; % GHz
Exp.CenterSweep = [339 10]; % mT

% Gaussian broadening
Sys.lwpp = 1; % mT
[B,spcG] = garlic(Sys,Exp);

% Lorentzian broadening
Sys.lwpp = [0 1]; % mT
[B,spcL] = garlic(Sys,Exp);

plot(B,spcG,B,spcL);

% Mixture of Gaussian and Lorentzian
Sys.lwpp = [0.3 0.6]; % mT
[B,spcGL] = garlic(Sys,Exp);

hold on % if you want to add another graph to an existing plot
plot(B,spcGL);
legend('Gauss','Lorentz','convolution');

% The lines have different intensities, because they have different shapes.
% Double integrals are identical.

% How to rescale a spectrum
clf
spcG = spcG/max(spcG);
spcL = spcL/max(spcL);
plot(B,spcG,B,spcL);
legend('Gaussian','Lorentzian');

% Sys.lw vs Sys.lwpp
% - use Sys.lwpp for peak-to-peak broadening in first-harmonic spectra
% - use Sys.lw for full width half max broadening in absorption spectra

%% EXERCISE 03-03: convolutional line broadenings
%{
Simulate the 9.8 GHz spectrum of an isotropic system with g = 2. Simulate it
once with Gaussian and once with Lorentzian convolutional broadening, and
plot the two spectra in the same plot. Use the same peak-to-peak broadening
of 0.1 mT = 1 G.
%}

clear, clc
Sys.g = 2;

Exp.mwFreq = 9.8;

Sys.lwpp = [0.1 0];
[B1,spc1] = garlic(Sys,Exp);
Sys.lwpp = [0 0.1];
[B2,spc2] = garlic(Sys,Exp);

plot(B1,spc1,B2,spc2);

%% DEMONSTRATION 03-04: isotropic hyperfine coupling
clf
clear
Sys.g = 2;
Sys.Nucs = '1H';
Sys.A = 100; % MHz
Sys.lwpp = 0.1; % mT
Exp.mwFreq = 9.6; % GHz
garlic(Sys,Exp);

% show that stick spectrum is calculated if linewidth is omitted or zero
Sys.lwpp = 0; % mT
garlic(Sys,Exp);

%% EXERCISE 03-04: hyperfine coupling
%{
Simulate the 9.85 GHz liquid-state spectrum of a radical with electron spin 1/2,
g value 2.003, coupled to one 2H with isotropic hfc of 18 G (remember that 1 G
is 2.8 MHz at g=2). Use a convolution p-p Lorentzian linewidth of 0.9 G (10 G =
1 mT).
%}
clear
Sys.S = 1/2;
Sys.g = 2.003;
Sys.Nucs = '2H';
Sys.A = 18*2.8; % MHz
Sys.lwpp = [0 0.09]; % mT
Exp.mwFreq = 9.85; % GHz
garlic(Sys,Exp);

%% DEMONSTRATION 03-05: equivalent nuclei
clc
Sys.Nucs = '1H';
Sys.n = 1;        % number of equivalent 1H
garlic(Sys,Exp);

% change to 2 (and more values), explain splitting pattern
Sys.n = 2;
garlic(Sys,Exp);

% change to 100, show that there are not enough points
Sys.n = 100;
garlic(Sys,Exp); % errors!

% increase no of points
Exp.nPoints = 1e5;
garlic(Sys,Exp);

% Lack of expected symmetry: second-order effect due to large HF!
% Reduce HF to 5 MHz -> symmetric

%% EXERCISE 03-05: equivalent nuclei
%{
Modify the simulation from the previous exercise to include 2 equivalent
deuterons. Repeat with 3 and 4 equivalent nuclei.
%}
Sys.n = 2;
garlic(Sys,Exp);

%% EXERCISE 03-05: equivalent nuclei
%{
Simulate the 9.3 GHz EPR spectrum of the pentacene radical anion. There are four
groups of equivalent protons with 2, 4, 4, and 4 protons each. The hyperfine
couplings are 4.26, 3.03, 0.92 and 0.87 G, respectively (1 G = 2.8 MHz). Use a
Lorentzian broadening with 0.1 G peak-to-peak. The g value is 2.003. Make sure
you use enough points to get an undistorted spectrum.
%}

clear, clc

Pc.g = 2.003;
Pc.Nucs = '1H,1H,1H,1H';
Pc.n = [2 4 4 4];
Pc.A = [4.26 3.03 0.92 0.87]*2.8; % G->MHz
%Pc.A = mt2mhz([4.26 3.03 0.92 0.87]/10); % MHz
Pc.lwpp = [0,0.01]; % mT

Exp.mwFreq = 9.3; % GHz

garlic(Pc,Exp);

%% DEMONSTRATION 03-06: harmonic
clear, clc

Sys.Nucs = '31P';
Sys.A = 40; % MHz
Sys.lwpp = 0.1; % mT

Exp.mwFreq = 9.3;
Exp.Harmonic = 0; [B,spc0] = garlic(Sys,Exp);
Exp.Harmonic = 1; [B,spc1] = garlic(Sys,Exp);
Exp.Harmonic = 2; [B,spc2] = garlic(Sys,Exp);

subplot(3,1,1); plot(B,spc0); axis tight
subplot(3,1,2); plot(B,spc1); axis tight
subplot(3,1,3); plot(B,spc2); axis tight

%% DEMONSTRATION 03-07: Field modulation
clear, clf
Sys.lwpp = 0.1; % mT
Exp.mwFreq = 9.5; % GHz
Exp.Range = [338 340]; % mT

Exp.ModAmp = 0.1; % modulation amplitude peak-to-peak; mT

[B,spc] = garlic(Sys,Exp);
plot(B,spc);

% run also with 0.5 mT to show overmodulation

%% DEMONSTRATION 03-08: Field modulation
% using a for loop to iterate of a range of modulation amplitudes
ModAmp = [0.1 0.2 0.5 1 2 5 10]*Sys.lwpp;
for k = 1:numel(ModAmp)
  Exp.ModAmp = ModAmp(k);
  [B,spc(k,:)] = garlic(Sys,Exp);
end
plot(B,spc);

%% EXERCISE 03-08: Field modulation
% Take the spectrum of the pentacene cation radical from above, and investigate
% the effect of using modulation amplitudes 0.02 mT (=0.2 G) and 0.1 mT (= 1 G).
% Plot the spectra in the same plot.

clear, clc

Pc.g = 2.003;
Pc.Nucs = '1H,1H,1H,1H';
Pc.n = [2 4 4 4];
Pc.A = mt2mhz([4.26 3.03 0.92 0.87]/10); % MHz
Pc.lwpp = [0,0.01]; % mT

Exp.mwFreq = 9.3; % GHz
Exp.nPoints = 1e4;
Exp.Range = [330 334]; % mT

Exp.ModAmp = 0.02; % mT
[B,spc1] = garlic(Pc,Exp);
Exp.ModAmp = 0.1; % mT
[B,spc2] = garlic(Pc,Exp);

plot(B,spc1,B,spc2);

%% DEMONSTRATION 03-09: Options, calculation method
% methyl radical (electron-irradiated liquid methane)
clear
Sys.g = 2;
Sys.Nucs = '1H';
Sys.n = 3;
Sys.A = 78; % MHz
Sys.lwpp = 0.01; % mT

Exp.mwFreq = 9.5; % GHz
Exp.nPoints = 1e4;
Exp.Harmonic = 0;

garlic(Sys,Exp);
% Notice that there is not a clear 1:3:3:1 pattern!

% Setting calculation options
Opt.Method = 'exact';
[B,spc0] = garlic(Sys,Exp,Opt);
Opt.Method = 'perturb1';
[B,spc1] = garlic(Sys,Exp,Opt);

plot(B,spc0,B,spc1);
legend('exact','perturb1');

% Opt.Verbosity: Seeing what garlic does
clc
Opt.Verbosity = 1;
[B,spc1] = garlic(Sys,Exp,Opt);

% Available options can be found on the garlic reference page

%% EXERCISE 03-09: Options; calculation method
%{
Calculate the 9.5 GHz EPR spectrum of a model system with S=1/2, g=2, 59Co, 200
MHz hfc, and lwpp of 0.3 mT. Use both the exact and the first-order perturbation
method. In addition, use Opt.Verbosity=1 to see garlic output to the command window.
%}
clear
Sys.g = 2;
Sys.Nucs = '59Co';
Sys.A = 200; % MHz
Sys.lwpp = 0.3; % mT

Exp.mwFreq = 9.5; % GHz

Opt.Method = 'exact';
[B,spc0] = garlic(Sys,Exp,Opt);
Opt.Method = 'perturb1';
[B,spc1] = garlic(Sys,Exp,Opt);

plot(B,spc0,B,spc1);
legend('exact','perturb1');
