%% EasySpin Academy 2020 - Session 4 - Solid-state EPR I
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%{
This session describes how to simulate solid-state EPR spectra, using
EasySpin's function pepper.

For each of the three main motional regimes, there is a dedicated simulation
function:
- liquid state: garlic
- slow motion: charli
- solid state: pepper
%}

%% DEMONSTRATION 04-01: Simple powder simulation
clear, clc
Sys.g = [2.10 2.10 2.56]; % a Ni(I) species

Sys.lwpp = 1; % convolutional Gaussian broadening, mT

Exp.mwFreq = 9.5; % GHz
% automatic field range
pepper(Sys,Exp);

% Manual field range
Exp.Range = [250 350]; % mT
pepper(Sys,Exp);

% Absorption spectrum
Exp.Harmonic = 0;
pepper(Sys,Exp);

% Get field axis and spectrum
[B,spc] = pepper(Sys,Exp);
plot(B,spc)

%% EXERCISE 04-01: Simple powder simulation
%{
The spin Hamiltonian parameters of a Cu(II) complex are gxy = 2.056, gz = 2.228,
Axy = 135 MHz, Az = 519 MHz (for 63Cu). Simulate and plot the CW EPR spectrum at
35 GHz. Use a convolutional Gaussian broadening with peak-to-peak width of 2 mT.
%}
clear
Cu.g = [2.056 2.228];
Cu.Nucs = '63Cu';
Cu.A = [135 519]; % MHz
Cu.lwpp = 2; % mT

Exp.mwFreq = 35; % GHz
%Exp.Range = [1080 1260]; % mT

pepper(Cu,Exp);

%% DEMONSTRATION 04-02: Strain broadenings
% In addition to convolutional broadening, EasySpin supports strain
% broadenings.
clear, clc
Sys.g = [2.00 2.19 2.37];  % mean g values 
Sys.gStrain = [0.02 0.03 0.1]; % width of distribution of g values

Exp.mwFreq = 9.5; % GHz
Exp.Range = [260 360]; % mT

pepper(Sys,Exp);

% different broadening types model different physical origins
% other strains: AStrain, DStrain, HStrain
% all assume distribution of value is much smaller than mean
% broadening page in EasySpin documentation

%% EXERCISE 04-02: Strain broadenings
%{
Take the Cu(II) simulation from above, remove the convolutional broadening, and
add g strain broadening of 0.005 along gx, gy, and gz. See what happens if you
change the gz strain broadening to 0.02.
%}
clear, clc
Cu.g = [2.056 2.228];
Cu.Nucs = '63Cu';
Cu.A = [135 519]; % MHz
Cu.lwpp = 2; % mT

Cu.gStrain = [0.005 0.005 0.02];

Exp.mwFreq = 35; % GHz
Exp.Range = [1060 1260]; % mT

pepper(Cu,Exp);

%% DEMONSTRATION 04-03: Tensor frames
clear
Sys.g = [2 2.1 2.2];
Sys.Nucs = '1H';
Sys.A = [60 120 200]; % MHz
Sys.lwpp = 0.2; % mT

Exp.mwFreq = 9.5; % GHz
Exp.Range = [300 350]; % mT

% A frame is collinear with molecular frame
Sys.AFrame = [0 0 0]; % in radians
[B,spc1] = pepper(Sys,Exp);
plot(B,spc1);

% A frame is tilted with respect to molecular frame
Sys.AFrame = [pi/2 0 0]; % rad
[B,spc2] = pepper(Sys,Exp);
plot(B,spc1,B,spc2);

%% EXERCISE 04-03: Tensor frames
%{
Take the system from the above demonstration and rotate the A tensor such that
the largest hf splitting appears at the mid-field feature and the smallest
splitting occurs at the low-field feature.
%}
Sys.AFrame = [pi/2 pi/2 0]; % radians
pepper(Sys,Exp);

%% DEMONSTRATION 04-04: Separate transition output
Opt.Output = 'separate';
pepper(Sys,Exp,Opt);

%% EXERCISE 04-04: Separate transition output
%{
Simulate the X-band absorption EPR spectrum of a frozen solution of a nitroxide
radical (14N, g = [2.0085 2.0065 2.003], A = [20 20 100] MHz, lwpp = 0.2 mT
Gaussian) and plot the three transitions separately.
%}
clear
Nx.g = [2.0085 2.0065 2.003];
Nx.Nucs = '14N';
Nx.A = [20 20 100]; % MHz
Nx.lwpp = 0.2; % mT
Exp.mwFreq = 9.5; % GHz
Exp.Harmonic = 0;
Opt.Output = 'separate';
pepper(Nx,Exp,Opt);

%% DEMONSTRATION 04-05: Orientational averaging
clear
Sys.g = [2 2.5];
Sys.lwpp = 0.5; % mT
Exp.mwFreq = 9.5; % GHz
pepper(Sys,Exp);

Opt.Verbosity = 1; % show verbosity

%Opt.nKnots = 10; % 10 is too small!
pepper(Sys,Exp,Opt);

% Include Opt.nKnots = 10
% Increase Opt.nKnots until spectrum is converged

% Opt.nKnots can take two numbers -> see documentation

%% EXERCISE 04-05: Orientational averaging
%{
Simulate a W-band (95 GHz) powder spectrum of an S=1/2 with rhombic g tensor (2,
2.2, 3) and convolutional Gaussian broadening of 5 mT peak-to-peak. Determine
the smallest value in Opt.nKnots needed to get a smooth converged spectrum.
Start with Opt.nKnots = 10.
%}
clear
Sys.g = [2 2.2 3];
Sys.lwpp = 5; % mT
Exp.mwFreq = 95; % GHz
Opt.nKnots = 40;
pepper(Sys,Exp,Opt);

% needs about Opt.nKnots = 40

%% DEMONSTRATION 04-06: Field and frequency spectra
% pepper (and other functions) can simulate both field-swept and frequency-
% swept spectra, with minimal change in the input.
clear
Sys.g = [2 2.2 3];
Sys.lwpp = 1; % mT

% field sweep
ExpB.mwFreq = 9.5; % GHz
ExpB.Harmonic = 0;
[B,spcB] = pepper(Sys,ExpB);

subplot(2,1,1)
plot(B,spcB);
xlabel('magnetic field (mT)');

% frequency sweep
ExpFreq.Field = 350; % mT
Sys.lwpp = 30; % MHz!
[nu,spcnu] = pepper(Sys,ExpFreq);

subplot(2,1,2)
plot(nu,spcnu);
xlabel('frequency (GHz)');

%% EXERCISE 04-06: Field and frequency spectra
%{
Calculate the frequency-swept spectrum at 1.2 T of a frozen solution of Cu(II)
with parameters g = [2.056 2.228], A(63Cu) = [135 519] MHz, and lwpp = 2 MHz.
Display the transitions separately.
%}

clear, clf
Cu.g = [2.056 2.228];
Cu.Nucs = '63Cu';
Cu.A = [135 519]; % MHz
Cu.lwpp = 50; % MHz

Exp.Field = 1200; % mT
Exp.mwRange = [33 39]; % GHz

Opt.Output = 'separate';
pepper(Cu,Exp,Opt);

%% DEMONSTRATION 04-07: Matrix diagonalization vs perturbation theory
clear, clc

Sys.g = [2.05 2.2];
Sys.Nucs = '63Cu,14N,14N';
Sys.A = [20 400; 10 20; 14 22]; % MHz
Exp.mwFreq = 9.5; % GHz

tic
Opt.Method = 'matrix';
[B,spc] = pepper(Sys,Exp,Opt);
toc

tic
Opt.Method = 'perturb1';
[B,spc_pt] = pepper(Sys,Exp,Opt);
toc

plot(B,spc,B,spc_pt);

%% EXERCISE 04-07: Matrix diagonalization vs perturbation theory
%{
Repeat the above simulation at S-band (3 GHz) and using 'matrix', 'perturb1',
and 'perturb2', plotting all the results in the same axes.
%}
Exp.mwFreq = 3;
Opt.Method = 'matrix';
[B,spcmd] = pepper(Sys,Exp,Opt);
Opt.Method = 'perturb1';
[B,spcp1] = pepper(Sys,Exp,Opt);
Opt.Method = 'perturb2';
[B,spcp2] = pepper(Sys,Exp,Opt);
plot(B,spcmd,B,spcp1,B,spcp2);
legend('matrix','pt1','pt2');
