%% EasySpin Academy 2020 - Session 9 - Slow-motion EPR
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%{
This session illustrates how to simulate EPR spectra of spin centers in the
slow-motional regime, i.e. spin centers that are "slowly" tumbling in solution.
EasySpin's function for this regime is chili(...).
%}

%% DEMONSTRATION 09-01: Basic simulation
clear
Sys.g = [2 2.1];
Sys.tcorr = 0.1*1e-9; % rotational correlation time, in seconds
Exp.mwFreq = 9.5; % GHz
Exp.Range = [320 342];   % mT
chili(Sys,Exp);

% Increase Sys.tcorr in steps (show context menu) up to 20 ns

% Show chili documentation
% Mention Sys.logtcorr, Sys.Diff, etc.

%% EXERCISE 09-01: Basic simulation, nitroxide
%{
Simulate the 9.5 GHz spectrum of a nitroxide radical with 1 ns rotational
correlation time. Use g = [2.008 2.0065 2.0023] and a 14N nucleus with A =
[20 20 100] MHz.
%}

clear
Sys.g = [2.008 2.0065 2.0023];
Sys.Nucs = '14N';
Sys.A = [20 20 100]; % MHz
Sys.tcorr = 1e-9; % s
Exp.mwFreq = 9.5; % GHz
chili(Sys,Exp);

%% DEMONSTRATION 09-02: Multiple timescales
% Plotting spectra for different values of the correlation time
clear

Exp.mwFreq = 9.5; % GHz
Exp.Harmonic = 0;
Exp.Range = [332 345]; % mT

Sys.g = [2.008 2.0065 2.0023];
Sys.Nucs = '14N';
Sys.A = [20 20 100]; % MHz

Sys.tcorr = 0.5e-9; [x1,spc1] = chili(Sys,Exp);
Sys.tcorr = 1.0e-9; [x2,spc2] = chili(Sys,Exp);
Sys.tcorr = 4.0e-9; [x3,spc3] = chili(Sys,Exp);

% calculate rigid-limit spectrum
Opt.Output = 'separate';
[x0,spc0] = pepper(Sys,Exp,Opt);

subplot(2,1,1)
plot(x1,spc1,x2,spc2,x3,spc3);
subplot(2,1,2)
plot(x0,spc0);

%% EXERCISE 09-02: Multiple timescales
%{
Simulate nitroxide spectra with 0.5 and 5 ns rotational correlation time and
plot them together in the same axes. Rescale the spectra so that they have
the same maximum.
%}
clear

Exp.mwFreq = 9.5; % GHz
Exp.Range = [332 346]; % mT

Sys.g = [2.008 2.0065 2.0023];
Sys.Nucs = '14N';
Sys.A = [20 20 100]; % MHz

Sys.tcorr = 0.5e-9; % s
[x1,y1] = chili(Sys,Exp);
Sys.tcorr = 5e-9; % s
[x2,y2] = chili(Sys,Exp);

y1 = y1/max(y1);
y2 = y2/max(y2);
plot(x1,y1,x2,y2);
axis tight

%% DEMONSTRATION 09-03: Anisotropic diffusion
clear, clf, clc

Exp.mwFreq = 9.5; % GHz
Exp.Harmonic = 0;

Sys.g = [2 2.2];
Sys.lwpp = 0.5; % mT

Sys.tcorr = [30 0.1]*1e-9; % in s, motional averaging is observable

[x0,y0] = pepper(Sys,Exp);
[x,y] = chili(Sys,Exp);

y0 = y0/max(y0);
y = y/max(y);
plot(x0,y0,x,y);

% Repeat with
%    Sys.tcorr = [30 0.1]*1e-9; % little motional averaging is observable
% Discuss issue with smoothness (convergence), Opt.LLMK.

%% EXERCISE 09-03: Anisotropic diffusion
%{
Simulate the slow-motion spectrum of a S=1/2 system with rhombig g tensor
g = [2.0 2.03 2.1] and rotational correlation time tcorr = [30 30 0.1]*1e-9,
i.e. fast rotation around the z axis. Compare this with tcorr = [30 30
30]*1e-9 and [30 0.1 30]*1e-9.
%}

Sys.g = [2 2.03 2.1];
Sys.lwpp = 0.5; % mT

Exp.mwFreq = 9.5; % GHz
Exp.Harmonic = 0;

Sys.tcorr = [30 30 30]*1e-9; % s
[B0,spc0] = chili(Sys,Exp);
Sys.tcorr = [30 30 0.1]*1e-9; % s
[Bz,spcz] = chili(Sys,Exp);
Sys.tcorr = [30 0.1 30]*1e-9; % s
[By,spcy] = chili(Sys,Exp);
plot(B0,spc0,Bz,spcz,By,spcy);

%% DEMONSTRATION 09-04: Basis size
clear, clc
Sys.g = [2 2.2];
Sys.tcorr = 30e-9; % s
Exp.mwFreq = 9.5; % GHz
Exp.Range = [300 350]; % mT
Exp.Harmonic = 0;

% Start with [2 0 0 0]
Opt.LLMK = [2 0 0 0]; % basis size

chili(Sys,Exp,Opt);

% iteratively increase Opt.LLKM(1) and others until spectrum is smooth
% minimal basis: [20 0 2 0]

%% EXERCISE 09-04: Nitroxide close to rigid limit
%{
Take the nitroxide simulation from demonstration 09-02. Set the rotational
correlation time to 100 ns. Set Opt.LLMK = [2 0 0 0] and observe the spectral
shape. Increase each number in Opt.LLMK in turn until spectrum doesn't change
anymore. Proceed from first to last number.
%}
clear, clc
Sys.g = [2.008 2.0065 2.0023];
Sys.Nucs = '14N';
Sys.A = [20 20 100]; % MHz
Sys.tcorr = 100e-9; % s
Exp.mwFreq = 9.5; % GHz

Opt.LLMK = [16 13 4 4];
chili(Sys,Exp,Opt);

% converged with Opt.LLMK = [16 13 4 4]

%% DEMONSTRATION 09-05: Partial ordering (single orientation)
% If a nitroxide radical is attached to a protein or embedded into a membrane,
% its rotational motion is hindered by its immediate environment. Some
% orientations are easier accessible than others. This is described by an
% orientational potential energy and given in Sys.Potential.
clear, clc
Sys.g = [2.008 2.0065 2.0023];
Sys.Nucs = '14N';
Sys.A = [20 20 100]; % MHz
Sys.tcorr = 1e-9; % seconds

% LMK and energy coefficient for orientational potential
% NEW IN EASYSPIN 6
Sys.Potential = [2 0 0 0.5];

% Plot orientational potential, and populations
% NEW IN EASYSPIN 6
oripotentialplot(Sys.Potential);

Exp.mwFreq = 9.5; % GHz
% If potential is given, chili by default assumes random orientations of the
% protein/membrane and runs a powder average. Let's fix the protein/membrane orientation.
Exp.CrystalOrientation = [0 0 0]; % radians

clf
Opt.Verbosity = 1;
Opt.LLMK = [6 0 2 2];
chili(Sys,Exp,Opt);

% change sign of lambda_200
% set lambda_200 to zero

% Disordered protein/membrane
Exp.CrystalOrientation = [];  % remove crystal orientation
Opt.nKnots = 8;   % increase this until spectrum is converged
chili(Sys,Exp,Opt);

%% EXERCISE 09-05a: Partial ordering, orientational average
%{
Take the nitroxide spectrum simulation from the demonstration, change Sys.tcorr
to 10 ns, and simulate the powder spectrum. Set Opt.nKnots=1 and increase it
until you obtain a converged spectrum.
%}

clear, clc
Sys.g = [2.008 2.0065 2.0023];
Sys.Nucs = '14N';
Sys.A = [20 20 100]; % MHz

Sys.Potential = [2 0 0 0.5];

Sys.tcorr = 10e-9; % seconds

Exp.mwFreq = 9.5; % GHz

Opt.nKnots = 1;
Opt.LLMK = [6 0 2 2];
chili(Sys,Exp,Opt);

%% EXERCISE 09-05b: Partial ordering
%{
Simulate the X-band spectrum of a simple S=1/2 system with g=[2 2.1] and
correlation time 5 ns. Fix the orientation by setting Exp.CrystalOrientation
to [0 0 0]. Run two simulations: one without ordering potential,
and one with [2 0 0 0.7]. Plot in the same figure.
%}
clear, clc, clf
Sys.g = [2 2.1];
Sys.tcorr = 5e-9; % seconds

Exp.mwFreq = 9.5; % GHz
Exp.Harmonic = 0;
Exp.Range = [320 345]; % mT
Exp.CrystalOrientation = [0 0 0]; % radians

Opt.LLMK = [8 0 2 0];
Sys.Potential = [2 0 0 0];
[B,spc0] = chili(Sys,Exp,Opt);
Sys.Potential = [2 0 0 0.7];
[B,spc1] = chili(Sys,Exp,Opt);
plot(B,spc0,B,spc1);

%% DEMONSTRATION 09-06: Two components
clear,clc
Nx1.g = [2.008 2.0065 2.0023];
Nx1.Nucs = '14N';
Nx1.A = [20 20 100]; % MHz
Nx1.tcorr = 5e-9; % seconds

Nx2 = Nx1;
Nx2.tcorr = 0.4e-9; % seconds

Nx1.weight = 0.99;
Nx2.weight = 0.01;

Exp.mwFreq = 9.5; % GHz
Exp.Range = [330 345]; % mT

chili({Nx1,Nx2},Exp);

% This type of input for two (or more) components also works for garlic,
% peppper, etc.

%% EXERCISE 09-06: Two components
%{
Simulate the two components of the above mixture separately and plot the 
resulting component spectra together with the sum.
%}
clc, clf
[B,spc1] = chili(Nx1,Exp);
[B,spc2] = chili(Nx2,Exp);
spc = spc1 + spc2;
plot(B,spc1,B,spc2,B,spc);
legend('comp.1','comp.2','sum');

%% DEMONSTRATION 09-07: Fast-motion regime
% If the rotational motion is fast, and if there is no orientational potential,
% garlic can be used instead of chili - it uses perturbation theory and is faster.
clear, clc
Sys.g = [2.008 2.0065 2.0023];
Sys.Nucs = '14N';
Sys.A = [20 20 100]; % MHz
Sys.tcorr = 0.3e-9; % seconds
Sys.lwpp = [0 0.05]; % mT

Exp.mwFreq = 9.5; % GHz

garlic(Sys,Exp);

% Always check against a chili() simulation whether the garlic() simulation
% is accurate.

%% EXERCISE 09-07: Fast-motion regime
%{
Take the nitroxide radical from the demonstration, set the correlation time to
0.5 ns, and simulate its X-band spectrum using both chili and garlic. Use a
manual field range. Plot the two spectra in the same plot. Then, increase the
correlation time tcorr. At what value of tcorr do the two simulations start to
diverge visually?
%}
clear, clc
Sys.g = [2.008 2.0065 2.0023];
Sys.Nucs = '14N';
Sys.A = [20 20 100]; % MHz
Sys.tcorr = 0.5e-9; % seconds
Sys.lwpp = [0 0.05]; % mT

Exp.mwFreq = 9.5; % GHz
Exp.Range = [332 344]; % mT
[B,spcg] = garlic(Sys,Exp);
[B,spcc] = chili(Sys,Exp);

spcg = spcg/max(spcg);
spcc = spcc/max(spcc);

plot(B,spcg,B,spcc);
legend('garlic','chili');

% Spectra start to diverge for tcorr >= about 2 ns.
