%% EasySpin Academy 2020 - Session 10 - Rapid-scan EPR
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)
%{
Rapid-scan EPR is a novel way of measuring EPR spectra, with significantly
increased sensitivity and time resolution. Commercial equipment has
recently become available.

Rapid-scan EPR uses field modulation just like CW EPR. However, there are two
differences that result in higher sensitivity. First, the modulation amplitude
is significantly larger. Second, the entire modulated signal is recorded, and
not just the first harmonic.

The raw signal is the deconvoluted with the field modulation shape, and this
yields the actual EPR spectrum.

This EPR spectrum is exactly the same as obtained for CW EPR. This means
that you can use the same EasySpin functions to simulate the spectra, i.e.
pepper() for solids, garlic() for liquids, chili() for slowmotion.
Basically, if you switch from standard CW EPR to rapid-scan EPR, you do not
have to change your EasySpin scripts.

EasySpin has two dedicated functions to simulate and manipulate raw signals
from rapid-scan EPR:
- blochsteady() for simulating them
- rapidscan2epr() for deconvolving them to get the spectrum

Let's look at each of them in turn.
%}

%% DEMONSTRATION 10-01: Raw rapid-scan signal
clear

g = 2.0023;
T1 = 2; % longitudinal relaxation time, us
T2 = 0.2; % transverse relaxation time, us

deltaB0 = 0; % field offset from resonance line, mT
ModAmp = 2; % peak-to-peak modulation amplitude, mT
ModFreq = 100; % modulation frequency, kHz
B1 = 0.01; % microwave magnetic field amplitude, mT

% Simulate raw rapid-scan signal (= steady-state solution of Block eq.)
blochsteady(g,T1,T2,deltaB0,B1,ModAmp,ModFreq);

% Change T2 to 0.5 us; discuss change in wiggle decay length
% Mention similarity to FID

% Revert, and change deltaB0 to 0.8; discuss change in position and wiggles

% Revert

% Extract data, plot separately
[t,Mabs] = blochsteady(g,T1,T2,deltaB0,B1,ModAmp,ModFreq);
[t,Mdis,Mabs,Mz] = blochsteady(g,T1,T2,deltaB0,B1,ModAmp,ModFreq);
clf
plot(t,Mabs,t,Mdis)
legend('absorption','dispersion')

%% EXERCISE 10-01: Raw rapid-scan signal
%{
Take the above example as a starting point. Simulate the rapid-scan signal
for different values of B1 (0.001, 0.01, 0.1) and plot all signal in the
same plot. Rationalize the observations.
%}

clf
B1 = 0.001;
[t,M1] = blochsteady(g,T1,T2,deltaB0,B1,ModAmp,ModFreq);
B1 = 0.01;
[t,M2] = blochsteady(g,T1,T2,deltaB0,B1,ModAmp,ModFreq);
B1 = 0.1;
[t,M3] = blochsteady(g,T1,T2,deltaB0,B1,ModAmp,ModFreq);
plot(t,M1,t,M2,t,M3);
legend('0.001 mT','0.01 mT','0.1 mT');

%% DEMONSTRATION 10-02: Deconvolution
% Deconvolve a rapid-scan signal to get the EPR spectrum
clear

% Simulate rapid-scan signal
g = 2.0023;
T1 = 2; % longitudinal relaxation time, us
T2 = 0.2; % transverse relaxation time, us
deltaB0 = 0; % field offset from resonance line, mT
ModAmp = 2; % peak-to-peak modulation amplitude, mT
ModFreq = 100; % modulation frequency, kHz
B1 = 0.01; % microwave magnetic field amplitude, mT
[t,Mx,My,Mz] = blochsteady(g,T1,T2,deltaB0,B1,ModAmp,ModFreq);

% Deconvolve to get the spectrum
rapidscan2spc(My+1i*Mx,ModAmp,ModFreq,g)

% Change T2 and discuss effect on spectrum

% Change deltaB0 and discuss effect on spectrum


%% EXERCISE 10-02: Deconvolution
%{
Simulate a rapid-scan raw signal with g = 2.0023, T1 = 2 us, T2 = 0.2 us,
on resonance, modulation amplitude 2 mT, modulation frequency 200 kHz, and
B1 field 0.01 mT. Then, deconvolve the signal to get the spectrum.
%}

clear, clc

% Simulate rapid-scan signal
g = 2.0023;
T1 = 2; % longitudinal relaxation time, us
T2 = 0.2; % transverse relaxation time, us
deltaB0 = 0; % field offset from resonance line, mT
ModAmp = 2; % peak-to-peak modulation amplitude, mT
ModFreq = 200; % modulation frequency, kHz
B1 = 0.01; % microwave magnetic field amplitude, mT
[t,Mx,My,Mz] = blochsteady(g,T1,T2,deltaB0,B1,ModAmp,ModFreq);

% Deconvolve to get the spectrum
rapidscan2spc(My+1i*Mx,ModAmp,ModFreq,g);

%% DEMONSTRATION 10-03: Apply field modulation
% Rapid-scan EPR, as well as pulse EPR, yield absorption spectra. To
% convert them to field-modulated spectra, use either deriv() or
% fieldmod().

clc, clf

% Simulate absorption spectrum
Sys.g = [2 2.1];
Sys.lwpp = 0.5;  % mT
Exp.mwFreq = 9.5; % GHz
Exp.Harmonic = 0;
[B,spc] = pepper(Sys,Exp);
plot(B,spc);

% Calculate derivative to get first-harmonic spectrum, low modamp limit
spcd = deriv(B,spc);
plot(B,spcd)

% For larger modulation amplitudes, use fieldmod()
ModAmp = 0.5; % mT
fieldmod(B,spc,ModAmp,1);

% Change ModAmp to 3 mT to show overmodulation

%% EXERCISE 10-03: Apply field modulation
%{
Simulate an isotropic 14N nitroxide absorption spectrum with g = 2.005,
A = 50 MHz, lwpp = 0.1 mT Lorentzian. Then use this to calculate the
first-harmonic spectrum with peak-to-peak modulation amplitudes 0.02 mT,
0.1 mT, and 0.5 mT. Plot in the same plot.
%}
clear, clc, clf

Nx.g = 2.005;
Nx.Nucs = '14N';
Nx.A = 50; % MHz
Nx.lwpp = [0 0.1]; % mT
Exp.mwFreq = 9.7;
Exp.Harmonic = 0;
Exp.Range = [342 349];
[B,spc] = pepper(Nx,Exp);
plot(B,spc);

spc1 = fieldmod(B,spc,0.02,1);
spc2 = fieldmod(B,spc,0.1,1);
spc3 = fieldmod(B,spc,0.5,1);

plot(B,spc1,B,spc2,B,spc3);
