%% EasySpin Academy 2020 - Session 11 - Least-squares fitting 3
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)
%{
This session demonstrates how to use EasySpin's least-squares function
esfit() to fit custom models via user-defined model simulation functions.

Two important use cases for this are:
- Couple several spin system parameters relative to each other.
- Fit experimental parameters (from the Exp structure).
%}

%% DEMONSTRATION 11-01: Couple spin system parameters

clear, clc, clf

% Fit a spectrum of a system with A tensors with fixed ratio

% Generate data
Sys.g = 2;
Sys.Nucs = '1H,1H,1H';
Sys.n = [2 3 2];
Sys.A = [20 30 50]; % MHz - ratio 1:1.5:2.5
Sys.lwpp = [0 0.1]; % mT

Exp.mwFreq = 9.5; % GHz
Exp.Range = [330 350]; % mT

[B,spc_exp] = garlic(Sys,Exp);
spc_exp = addnoise(spc_exp,100,'f');
plot(B,spc_exp);

% First, let's try to fit 3 hyperfine constants separately
Vary.A = [5 8 12];
esfit(@garlic,spc_exp,Sys,Vary,Exp);
% This is difficult - the error surface has many minima

% Define a separate model function that uses the information about the fixed
% ratio between the hyperfine couplings, and the simulates the data
% -> mysimfun further down

% Define start and vary values for a new custom parameter (using "my" prefix)
Sys.myA = 20;
Vary.myA = 5;

% CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE
esfit(@mysimfun,spc_exp,Sys,Vary,Exp);

% Put this function at the end of the script
%{
function y = mysimfun(Sys,Exp,Opt)
Sys.A = Sys.myA*[1 1.5 2.5];
y = garlic(Sys,Exp,Opt);
end
%}

%% EXERCISE 11-01: Couple spin system parameters
%{
Simulate the X-band EPR spectrum of a S=1/2 spin system with one proton 1H
and hyperfine tensor [5 7 12] MHz. Fit the hyperfine tensor, assumiung
that you know the symmetry of the tensor (i.e. the relative ratioes of the 
three principal components), but not the overall scale. This could be the
case if you have an idea about the symmetry from DFT calculations, but the
spin density is unclear.
%}

clear, clc
Sys.g = 2;
Sys.Nucs = '1H';
Sys.A = [5 7 12];
Sys.lwpp = 0.01;
Exp.mwFreq = 9.5;
[B,spc] = pepper(Sys,Exp);
spc = addnoise(spc,100,'f');
plot(B,spc);

Sys.myAscale = 1.1;
Vary.myAscale = 0.3;

% CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE
esfit(@mysimfun2,spc,Sys,Vary,Exp);

% Put this function at the end of the script
%{
function mysimfun2(Sys,Exp,Opt)
Sys.A = Sys.myAscale*[5 7 12];
y = pepper(Sys,Exp,Opt);
end
%}

%% DEMONSTRATION 11-02: Couple spin system parameters
clear, clc

Sys.S = 3/2;
Sys.D = 100e3*[1 0.1];
Sys.lwpp = 5;

Exp.mwFreq = 9.5;
Exp.Range = [50 500];
Exp.Temperature = 10;

Opt.Transitions = [1 2]; % just simulate the most intense transition
Opt.nKnots = 50; % needed to render spectrum smooth

[B,spc] = pepper(Sys,Exp,Opt);
spc_exp = addnoise(spc,100,'f');

plot(B,spc_exp);

% Show that spectrum is independent of D, but depends on E/D

% Since spectrum depends only on E/D, it makes sense to use this a 
% parameter. But Sys doesn't allow that directly. Solution: define a
% custum model simulation function.

Sys.myEoD = 0.15;
Vary.myEoD = 0.15;

% CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE
esfit(@mysimfun,spc_exp,Sys,Vary,Exp);

% Put this function at the end of the script
%{
function y = mysimfun(Sys,Exp,Opt)
Sys.D = 100e3*[1 Sys.myEoD];
y = pepper(Sys,Exp,Opt);
end
%}
%% EXERCISE 11-02: Couple spin system parameters
%{
Repeat the simulation and fit of the above demonstration, using S=5/2.
%}

%% DEMONSTRATION 11-03: Fit experimental parameters
% This approach can be used to fit experimental parameters from the
% Exp structure, e.g. mwPhase or Temperature or Range:

% Here is an example for temperature
% High-spin systems with significant zero-field splittings have
% temperature-dependent intensities at low temperatures - this is used
% to determine the sign of D.
% We can use the spectrum to determine the actual sample temperature.

clear, clc

% Simulate a W-band spectrum of a triplet at low temperature
Sys.S = 1;
Sys.D = 10e3; % MHz  (large ZFS)
Sys.lwpp = 30; % mT
Exp.Temperature = 4; % K
Exp.mwFreq = 95; % GHz
Exp.Range = [2800 4000];
[B,spc] = pepper(Sys,Exp);
spc = addnoise(spc,100,'f');
plot(B,spc);

% Now define temperature a custom field in the Sys structure
Sys.myTemp = 5;    % custom parameter, ignored by pepper()
Vary.myTemp = 5;   % tell esfit() to include in the fit
% and use a custom function to copy that into the Sys structure.

% Call esfit with the custom function
% CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE
esfit(@mysimfun,spc,Sys,Vary,Exp);

%{
function y = mysimfun(Sys,Exp,Opt)
Exp.Temperature = Sys.myTemp;
y = pepper(Sys,Exp,Opt);
end
%}

%% EXERCISE 11-03: Fitting experimental parameters
%{
This exercise is about fitting a field shift, given a known g factor.
Simulate a spectrum with g = 2.003 at 9.5 GHz with a field range that
includes a random shift Exp.Range = [332 348] + (2*rand-1)*2. This simulates
the fact that there is typically a small offset between the recorded field
and the actual field at the sample.
Write a custom fit function that will allow you to determine this shift via
least-squares fitting with esfit.
%}
clear, clc
Sys.g = 2.003;
Sys.lwpp = [0 1]; % mT
Exp.mwFreq = 9.5; % GHz
Bshift = (2*rand-1)*2
Exp.Range = [332 348] + Bshift; % mT
[B,spc_exp] = pepper(Sys,Exp);
spc_exp = addnoise(spc_exp,20,'f');

plot(B,spc_exp);
xlim([332 348]);

Sys0 = Sys;
Sys0.myBshift = 0;
Vary.myBshift = 2;
% CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE
esfit(@mysimfun,spc_exp,Sys0,Vary,Exp);

function y = mysimfun(Sys,Exp,Opt)
Exp.Range = [332 348] + Sys.myBshift;
y = pepper(Sys,Exp,Opt);
end
