%% EasySpin Academy 2020 - Session 12 - Pulse EPR
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%{
This session explores how EasySpin's function saffron() is used to
simulate basic pulse EPR spectra.
%}

%% DEMONSTRATION 12-01: Pulse EPR
clear
Sys.g = 2;
Sys.Nucs = '1H';
Sys.A = [3 6]; % MHz

% Set field - pulse EPR experiments are performed at fixed field
Exp.Field = 350; % mT

Exp.Sequence = '2pESEEM';
Exp.dt = 0.010; % microseconds

% Without requesting outputs, saffron plots the results of the simulation
saffron(Sys,Exp);

% Add T2 (simple exponential decay)
Sys.T2 = 10; % microseconds
saffron(Sys,Exp);

% Increase hyperfine to [10 40], discuss spectral changes, simulation noise
Sys.A = [10 40];
saffron(Sys,Exp);

% Show that Opt.nKnots needs to be increased
Opt.nKnots = 40; % reasonably converged at 200
saffron(Sys,Exp,Opt);

% Decrease HF couping with 0.1-1 prefactor and observe spectral changes

% Show saffron help: list of predefined pulse sequences, parameters for
% predefined pulse sequence

%% EXERCISE 12-01: Pulse EPR
%{
Simulate the two-pulse ESEEM time-domain signal and spectrum at 1100 mT of
an S=1/2 coupled to a 14N with hyperfine tensor [-1,-1,2] MHz and quadrupole
coupling Q = 1 MHz. Use a time increment of 20 ns and 500 points. Make sure
to increase Opt.nKnots until the time-domain signal doesn't change anymore.
%}

clear
Sys.g = 2;
Sys.Nucs = '14N';
Sys.A = [-1 -1 2]; % MHz
Sys.Q = 1; % MHz

Exp.Field = 1100; % mT

Exp.Sequence = '2pESEEM';
Exp.dt = 0.020; % microseconds
Exp.nPoints = 500;

Opt.nKnots = 50;
saffron(Sys,Exp,Opt);

%% DEMONSTRATION 12-02: HYSCORE
clear, clc

Sys.Nucs = '1H';
Sys.A = [-5 20]; % MHz, strongly anisotropic

Exp.Field = 350; % mT

Exp.Sequence = 'HYSCORE';
Exp.tau = 0.010; % microseconds
Exp.dt = 0.016; % microseconds

Opt.nKnots = 200;
saffron(Sys,Exp,Opt);

% Demonstrate dependence on Exp.tau (reduce from 200ns)

% Demonstrate dependence on Opt.nKnots

%% EXERCISE 12-02: Three-pulse ESEEM
%{
Simulate the three-pulse ESEEM experiment for the spin system in the
previous demonstration. Use a tau value of 120 ns, a time increment of
16 ns, and 200 points.
%}
clear, clc
Sys.Nucs = '1H';
Sys.A = [-5 20]; % MHz, strongly anisotropic

Exp.Field = 350; % mT

Exp.Sequence = '3pESEEM';
Exp.tau = 0.010; % microseconds
Exp.dt = 0.016; % microseconds
Exp.nPoints = 200;

Opt.nKnots = 181;
saffron(Sys,Exp,Opt);

%% DEMONSTRATION 12-03: Excitation bandwidth

clear, clc
Sys.g = 2;
Sys.Nucs = '1H';
Sys.A = [5 10]; % MHz, strongly anisotropic
Exp.Field = 350; % mT

Exp.Sequence = '2pESEEM';
Exp.tau = 0.120; % microseconds
Exp.dt = 0.012; % microseconds
Exp.nPoints = 300;
Opt.nKnots = 91;
saffron(Sys,Exp,Opt);

% Simulate frequency-swept EPR spectrum to see where the resonances are
clf
cwExp.Field = 350;
cwExp.mwRange = [9.7 9.9];
subplot(2,1,1)
pepper(Sys,cwExp)

% Limit excitation window: give microwave frequency and excitation width
Exp.mwFreq = 9.797;
Exp.ExciteWidth = 100;

% Ask saffron for outputs, so we can plot results ourselves
[t,V,result] = saffron(Sys,Exp,Opt);

% Draw line at resonance frequency
subplot(2,1,1)
xline(Exp.mwFreq,'color','r');

subplot(2,1,2);
plot(result.f,abs(result.fd))

% Change mwFreq to show effect of offset
% Change 

%Exp.mwFreq = mt2mhz(Exp.Field,Sys.g)

%% EXERCISE 12-03: Excitation bandwidth
%{
Take the simulation from the previous demonstration, set the microwave
frequency to be at the center of the EPR spectrum using mt2mhz(), and reduce
the excitation width until you see a reduction of spectral intensity in the
ESEEM spectrum. What is the minimum required width to get good signal?
%}

clear, clc
Sys.g = 2;
Sys.Nucs = '1H';
Sys.A = [5 10]; % MHz, strongly anisotropic
Exp.Field = 350; % mT

Exp.Sequence = '2pESEEM';
Exp.tau = 0.120; % microseconds
Exp.dt = 0.012; % microseconds
Exp.nPoints = 300;

Exp.mwFreq = mt2mhz(Exp.Field,Sys.g)/1e3; % MHz -> GHz
Exp.ExciteWidth = 8;

Opt.nKnots = 91;
Opt.Verbosity = 1;
saffron(Sys,Exp,Opt);


%% DEMONSTRATION 12-04: Custom sequence

% USe Exp.Sequence, Exp.Dim1, and Exp.nPoints to create a custom pulse
% sequence.

clear

Sys.S = 1/2;
Sys.Nucs = '1H';

% Mention A_ for isotropic and axial components of hyperfine
Sys.A_ = [5 2]; % MHz

Exp.Field = 350; % mT

% Define custom pulse sequence
p90.Flip = pi/2; % rad
tau = 0.01; % µs
T0 = 0.06; % µs
Exp.Sequence = {p90 tau p90 T0 p90 tau};

% Define incrementation scheme
Exp.Dim1 = {'d2', 0.005}; % µs
Exp.nPoints = 512;

Opt.nKnots = 50;

saffron(Sys,Exp,Opt);

% Mention phase cycling with Exp.PhaseCycle

% Mention detection window with Exp.DetWindow

% Show user guide

% Show examples

%% EXERCISE 12-04: Custom sequence
%{
Take the previous demonstration and change the pulse sequence to a
two-pulse ESEEM.
%}

clear
Sys.S = 1/2;
Sys.Nucs = '1H';
Sys.A_ = [5 2]; % MHz

Exp.Field = 350; % mT
p90.Flip = pi/2; % rad
p180.Flip = pi; % rad
tau0 = 0.01; % µs
Exp.Sequence = {p90 tau0 p180 tau0};

% Define incrementation scheme
Exp.Dim1 = {'d1,d2', 0.005}; % µs
Exp.nPoints = 512;

Opt.nKnots = 90;
saffron(Sys,Exp,Opt);
