%% EasySpin Academy 2020 - Session 13 - Other tools
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%{
This session demonstrates some of EasySpin's capabilities beyond the EPR
spectrum simulation and fitting functions. There is much more to this than
we can show in this session, so refer to the categorical list of functions
to find out more.
%}

%% DEMONSTRATION 13-01: Physical constants
% show list of physical constants
nu = 263e9; % Hz
g = 2;
B = planck*nu/bmagn/g % T

% useful for conversions
% see also mhz2mt and mt2mhz
mhz2mt(95000,2.1)

% interactive tool for field/frequency/g conversions
eprconvert

% calculate nuclear Larmor frequency
nuL = larmorfrq('1H',350) % MHz

%% EXERCISE 13-01: Physical constants
%{
(a)
Convert A = 13*10^-4 cm^-1 to MHz: (1) convert to m^-1, (2) multiply by
speed of light to get s^-1 = Hz, (3) divide by 1e6 to get MHz
(b)
Calculate the Larmor frequency of 15N and 13C at W-band field (3.3 T).
%}
% (a)
clc
A_cm = 13*1e-4; % 1e-4 cm^-1 -> m^-1
A_m = A_cm*100; % cm^-1 -> m^-1
A_MHz = A_cm*100*clight/1e6   % MHz

% (b)
larmorfrq('15N,13C',3300) % MHz

%% DEMONSTRATION 13-02: Spin operator matrices
clear
Sx = sop(1/2,'x')
Sx = sop(5/2,'x')
[Sx,Sy,Sz] = sop(1/2,'x','y','z');

%% EXERCISE 13-02: Spin operator matrices
%{
Calculate the spin operator matrices Sz, S+, and S- for a triplet spin (S = 1).
%}
clear, clc
[Sx,Sp,Sm] = sop(1,'z','+','-')

%% DEMONSTRATION 13-03: Spin operator matrices for multi-spin systems
clear, clc
Spins = [1/2 1/2]
Sx = sop(Spins,'x1')
Iz = sop(Spins,'z2')
SzIx = sop(Spins,'zx')

%% EXERCISE 13-03: Spin operator matrices for multi-spin systems
%{
Calculate the spin operator S1+S2- for an S1=S2=1/2 system.
%}
clear, clc
S1pS2m = sop([1/2 1/2],'+-')

%% DEMONSTRATION 13-04: Spin Hamiltonian
clear
Sys.S = 1/2;
Sys.g = 2;
B = [0; 0; 350]; % mT

% full Hamiltonian
H = sham(Sys,B)

% units for all Hamiltonians: MHz

% part of the spin Hamiltonian can be extracted separately
Sys.Nucs = '1H';
Sys.A = [10 30 80];
Hhf = hfine(Sys)
Hze = zeeman(Sys,B)

%% EXERCISE 13-04: Spin Hamiltonian
%{
Build the spin Hamiltonian for a nitroxide radical with g = [2.008 2.0065
2.0023], a 14N nucleus with A = [20 100] MHz, and the magnetic field of 330 mT
along the molecular x axis.
%}
clear
Nx.g = [2.008, 2.0065, 2.0023];
Nx.Nucs = '14N';
Nx.A = [20, 100]; % MHz
B = [350; 0; 0]; % mT
H = sham(Nx,B)

%% DEMONSTRATION 13-05: Eigenvalues and eigenvectors
clc
% Take nitroxide from previous exercise

% Just eigenvalues
E = eig(H)

% to get all transition frequencoes
E-E'

% Eigenvectors and eigenvalues
[V,E] = eig(H)

%% EXERCISE 13-05: Eigenvalues and eigenvectors
%{
Take the nitroxide radical from above, and calculate the energy levels for the
situation where the field is 380 mT strong and along the molecular y axis.
%}
clc
B = [0; 380; 0]; % mT
H = sham(Nx,B);
E = eig(H)

%% DEMONSTRATION 13-06: Energy level diagram
clear, clc
Sys.S = 1;
Sys.D = 5e3*[1 0.1]; % MHz
Brange = [0 600]; % mT

% without transitions
levelsplot(Sys,'z',Brange);

% include transitions
mwFreq = 9.5; % GHz
levelsplot(Sys,'z',Brange,mwFreq);

% different orientations
levelsplot(Sys,'x',Brange,mwFreq);
levelsplot(Sys,[pi/3 pi/4],Brange,mwFreq);


%% EXERCISE 13-06: Energy level diagram
%{
Plot the energy level diagram for the H atom. It is a spin-1/2 coupled to a 1H
nucleus with isotropic hyperfine coupling of 1.4 GHz. Use a field range from 0
to 500 mT. Add resonances for a microwave frequency of 9.5 GHz.
%}

clear
Sys.Nucs = '1H';
Sys.A = 1400; % MHz
levelsplot(Sys,'z',[0 500],9.5);

%% DEMONSTRATION 13-07: Line shapes
clear, clc, clf

% Gaussian and Lorentzian lineshapes
B = linspace(300,400,1001);
Bcenter = 340; % mT
fwhm = 10; % mT
yG = gaussian(B,Bcenter,fwhm);
yL = lorentzian(B,Bcenter,fwhm);

plot(B,yG,B,yL);
legend('Gaussian','Lorentzian');

% show integral is approx. 1
dx = B(2)-B(1);
sum(yG)*dx
sum(yL)*dx

% vary derivative
d = 2;
yG = gaussian(B,Bcenter,fwhm,d);
yL = lorentzian(B,Bcenter,fwhm,d);
plot(B,yG,B,yL);

% Voigtian = convolution of Gaussian and Lorentzian
fwhmG = 10;
fwhmL = 3;
yGL = voigtian(B,Bcenter,[fwhmG fwhmL],d);

plot(B,yG,B,yL,B,yGL);
legend('Gaussian','Lorentzian','Voigtian = convolution');

%% EXERCISE 13-07: Line shapes
%{
Construct and plot a four-line EPR spectrum with lines at 310, 320, 330, and
340 mT, with an intensity ratio of 1:3:3:1, all lines first-derivative
Lorentzians with FWHM of 2 mT.
%}
clear
B = linspace(300,350,1001); % mT
fwhm = 2; % mT

B0 = [310 320 330 340]; % mT
intensity = [1 3 3 1];
spc = 0;
for k = 1:4
  spc = spc + intensity(k)*lorentzian(B,B0(k),fwhm,1);
end
plot(B,spc);
