%% EasySpin Academy 2020 - Session 14 - ENDOR
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%{
This session explores how EasySpin's function salt() can
simulate ENDOR spectra.
%}

%% DEMONSTRATION 14-01: Simple ENDOR spectrum
clear, clc

Sys.g = 2;
Sys.Nucs = '1H';
Sys.A = 10; % MHz
Sys.lwpp = 0.01; % mT

% Plot EPR frequency spectrum first

ExpEPR.mwFreq = 9.5225; % GHz

subplot(2,1,1);
pepper(Sys,ExpEPR);

% Then the ENDOR spectrum:

ExpEndor.Field = 352.3; % mT
ExpEndor.Range = [0 30]; % MHz

Sys.lwEndor = 0.2; % MHz

subplot(2,1,2);
salt(Sys,ExpEndor);

% Add a line marking the nuclear Larmor frequency
nuH = larmorfrq('1H',ExpEndor.Field);
xline(nuH);

% Rerun with Sys.Nucs = '1H,1H,1H' and Sys.A = [10,3,2]
Sys.Nucs = '1H,1H,1H';
Sys.A = [10,3,2]; % MHz

%% EXERCISE 14-01: Simple ENDOR simulation
%{
Starting from the example of the demonstration, use a spin system with S=1/2 and
6 protons, with isotropic hfcs of 10, 10, 20, 14, 4, and 9 MHz. Simulate both the
absorption EPR spectrum and the ENDOR spectrum. Use an Gaussian EPR broadening
of 0.02 mT and an ENDOR broadening of 0.2 MHz. Plot them in two separate subplots.
%}
clear, clc

Sys.g = 2;
Sys.Nucs = '1H,1H,1H,1H,1H,1H';
Sys.A = [10 10 20 14 4 9]; % MHz
Sys.lwpp = 0.02; % mT

ExpEPR.mwFreq = 9.5225; % GHz

subplot(2,1,1);
pepper(Sys,ExpEPR);

ExpEndor.Field = 352.3; % mT
ExpEndor.Range = [0 30]; % MHz

Sys.lwEndor = 0.2; % MHz

subplot(2,1,2);
salt(Sys,ExpEndor);

%% DEMONSTATION 14-02: ENDOR of anisotropic system
clear, clf

Sys.g = 2;
Sys.Nucs = '1H';
Sys.A = [5 10]; % MHz

Sys.lwEndor = 0.2; % MHz

Exp.Field = 350; % mT
Exp.Range = [5 25]; % MHz

salt(Sys,Exp);

% The slight asymmetry is due to second-order effects - the lower-frequency
% peak is a bit narrower and therefore a bit more intense than the higher-
% frequency peak.

% If we go to W band, then this difference vanishes
Exp.Field = 3350; % mT
Exp.Range = [135 150]; % MHz
salt(Sys,Exp);

%% EXERCISE 14-02: ENDOR of anisotropic system
%{
Start from the demonstration script, change the hyperfine coupling to [50 55 70]
MHz and simulate the ENDOR spectrum. Discuss the location of the peaks.
%}
clear, clf

Sys.g = 2;
Sys.Nucs = '1H';
Sys.A = [50 55 70]; % MHz

% ENDOR spectrum
Sys.lwEndor = 0.2; % MHz

Exp.Field = 350; % mT
Exp.Range = [0 60]; % MHz

salt(Sys,Exp);

% Demonstration was weak-coupling case (A/2<nuH), this is strong-coupling case
% (A/2>nuH). Range needed to expand.

%% DEMONSTRATION 14-03: Orientation selection

clear, clc, clf

% system with large anisotropy and a small hf
Sys.g = [1.9 1.98 2.12];
Sys.Nucs = '1H';
Sys.A = [5 10]; % MHz
Sys.lw = 5; % MHz

Exp.Field = 350; % mT
Exp.nPoints = 1e4;
Exp.Harmonic = 0;

% let's look at frequency spectrum (fixed field - that's how ENDOR is done)
subplot(2,1,1)
pepper(Sys,Exp);

% reduce Sys.lw to 1 MHz to show that hf splitting is there

% set ENDOR linewidth (convolutional)
Sys.lwEndor = 0.2; % MHz

% infinite-bandwidth ENDOR (not realizable experimentally)
ExpEndor.Field = Exp.Field;
ExpEndor.Range = [5 30]; % MHz
[nu,spc0] = salt(Sys,ExpEndor);

% limited microwave excitation bandwidth
ExpEndor.mwFreq = 9.7; % GHz
ExpEndor.ExciteWidth = 50; % MHz
Opt.nKnots = 100;
[nu,spc1] = salt(Sys,ExpEndor,Opt);

subplot(2,1,2);
plot(nu,spc0/max(spc0),nu,spc1/max(spc1))
xlabel('frequency (MHz)');

subplot(2,1,1)
xline(ExpEndor.mwFreq,'r');
xline(ExpEndor.mwFreq-ExpEndor.ExciteWidth/1e3,'r--');
xline(ExpEndor.mwFreq+ExpEndor.ExciteWidth/1e3,'r--');

% show how Opt.nKnots affects ENDOR spectrum accuracy

% move ExpEndor.mwFreq between 9.3 and 10.4 GHz and
% show how ENDOR spectrum changes

%% EXERCISE 14-03: Orientation selection
%{
Take the spin system from the demonstration script and add a second 1H with A =
[1 4 1] MHz. Then simulate the ENDOR spectrum (350 mT; 0.2 MHz lwEndor) with
infinite excitation bandwidth, and then with 50 MHz excitation bandwidth centered
at the low-frequency edge (9.3 GHz) and at the high-frequency edge (10.4 GHz)
of the EPR spectrum. Rationalize the positions of the peaks.
%}
clear, clc, clf

% system with large anisotropy and a small hf
Sys.g = [1.9 1.98 2.12];
Sys.Nucs = '1H,1H';
Sys.A = [5 5 10; 1 4 1]; % MHz
Sys.lwEndor = 0.2;

% infinite-bandwith ENDOR (not realizable experimentally)
ExpEndor.Field = 350;
ExpEndor.Range = [5 30]; % MHz
ExpEndor.mwFreq = 9.3; % GHz

ExpEndor.ExciteWidth = inf; % MHz
[nu,spc0] = salt(Sys,ExpEndor);

Opt.nKnots = 120;
ExpEndor.ExciteWidth = 50; % MHz
[nu,spc1] = salt(Sys,ExpEndor,Opt);

plot(nu,spc0/max(spc0),nu,spc1/max(spc1))

%% DEMONSTRATION 14-04: ENDOR with saffron

% Mention that saffron() simulates Mims-ENDOR spectra with
% Exp.Sequence = 'MimsENDOR'
