%% EasySpin Academy 2020 - Session 15 - Pulse shaping
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%{
This session discusses shaped pulses in EPR. In EasySpin, three major
functions deal with shaped pulses:
- pulse() computes pulse shapes from frequency and amplitude modulation functions.
- saffron() simulates predefined and arbitrary pulse sequences for any
  kind of spin system.
- spidyan() allows investigation of spin dynamics.
%}

%% DEMONSTRATION 15-01: Basic usage of pulse()
%{
pulse() calculates pulse amplitude, frequency and phase modulation functions
for many different pulse types. Without output arguments, it plots a figure
that shows the time domain, frequency modulation function and frequency-domain
excitation band of the pulse.
%}

clear
Par.Type = 'rectangular';
Par.tp = 0.020; % pulse length, s
Par.Frequency = 1000; % pulse frequency sweep range, MHz
Par.Flip = pi/2; % flip angle in radians

pulse(Par)

%% EXERCISE 15-01: Basic pulse shaping, monochromatic pulses
%{
Design a monochromatic rectangular pulse with an amplitude of 25 MHz and
a length of 10 ns. Compare its excitation bandwidth to the one of a mono-
chromatic Gaussian pulse with a length of 40 ns, an amplitude of 70 MHz and
a FWHM parameter of 10 ns (Par.tFWHM). Let both pulses have a frequency of 1 GHz.
%}

clear

Rect.Type = 'rectangular';
Rect.tp = 0.010; % s
Rect.Frequency = 1000; % MHz
Rect.Amplitude = 25; % pulse amplitude in MHz

pulse(Rect)

Gauss.Type = 'gaussian';
Gauss.tp = 0.040; % s
Gauss.Frequency = 1000; % MHz
Gauss.Amplitude = 70; % MHz
Gauss.tFWHM = 0.02; % FHWM time in s

pulse(Gauss)

%% DEMONSTRATION 15-02: FM/AM functions, hyperbolic secant pulse
%{
Here, a hyperbolic secant pulse with a bandwidth of 200 MHz is created.
The pulse shape is contained in IQ (in-phase signal as real part, 
quadrature signal in the imaginary part). This is used to calculate an
excitation profile.
%}

clear, close, clc

HS.Type = 'sech/tanh'; % pulse shape
HS.tp = 0.200; % s
HS.Frequency = [-100 100]; % pulse frequency sweep range, MHz
HS.beta = 8; % truncation parameter, used as (beta/tp)
HS.Flip = pi; % radians

% Call pulse() and let it plot the results
pulse(HS)

close all

% Call pulse() to get t and IQ back
[t, IQ] = pulse(HS); 

subplot(1,2,1)
plot(t,real(IQ),t,imag(IQ))
xlabel('{\it t} (s)')
ylabel('\nu_1 (MHz)')

% Call exciteprofile() to calcuate excitation profile
[offsets,M] = exciteprofile(t,IQ);

subplot(1,2,2)
plot(offsets,M(1,:),offsets,M(2,:),offsets,M(3,:))
xlabel('\Delta\nu (MHz)')
ylabel('M_i/M_0')
legend('x','y','z')

%% EXERCISE 15-02: Advanced pulse shaping, chirp pulses
%{
Now design two pulses. Let both pulses have a WURST AM, a linear FM.
First look up the documentation for pulse() and find out what parameters are
needed for this pulse shape. Both pulses should sweep from +150 MHz to -150
MHz and have an order (nwurst) of 8. The first pulse should have a length of
200 ns and a flip angle of pi. The second pulse should have half the length
of the first pulse and flip angle of pi. Plot IQ and excitation profiles for
both pulses in a single figure (4 subplots). What is the bandwidth of the 
pulses? What do you notice about the amplitude?
%}

clear, close all

WURST{1}.Type = 'WURST/linear'; % pulse shape, linear chirp with WURST amplitude modulation
WURST{1}.tp = 0.200; % s
WURST{1}.Frequency = [150 -150]; % MHz
WURST{1}.nwurst = 8; % order of pulse
WURST{1}.Flip = pi; % radians

WURST{2}.Type = 'WURST/linear'; 
WURST{2}.tp = 0.100; % s
WURST{2}.Frequency = [150 -150]; % MHz
WURST{2}.nwurst = 8;
WURST{2}.Flip = pi; % radians

[t{1},IQ{1}] = pulse(WURST{1});
[t{2},IQ{2}] = pulse(WURST{2});

[offsets{1},M{1}] = exciteprofile(t{1},IQ{1});
[offsets{2},M{2}] = exciteprofile(t{2},IQ{2});

% Plotting
subplot(2,2,1)
title('\pi/2 pulse');
plot(t{1},real(IQ{1}),t{1},imag(IQ{1}))
xlabel('t (\mus)')
ylabel('\nu_1 (MHz)')

subplot(2,2,2)
plot(t{2},real(IQ{2}),t{2},imag(IQ{2}))
xlabel('t (\mus)')
ylabel('\nu_1 (MHz)')

subplot(2,2,3)
plot(offsets{1},M{1}(1,:),offsets{1},M{1}(2,:),offsets{1},M{1}(3,:))
xlabel('\Delta\nu (MHz)')
ylabel('M_i/M_0')
legend('x','y','z')

subplot(2,2,4)
plot(offsets{2},M{2}(1,:),offsets{2},M{2}(2,:),offsets{2},M{2}(3,:))
xlabel('\Delta\nu (MHz)')
ylabel('M_i/M_0')
legend('x','y','z')

%% DEMONSTRATION 15-03: saffron, two-pulse echo with WURST pulses
%{
Define a spin system, look at its spectrum and position the pulses. Then
run the simulation and plot the signal.
%}

close all

% Spin system
Sys.g = [2.009 2.006 2.002];
Sys.A = [11 11 95]; % MHz
Sys.Nucs = '14N';
Sys.lwpp = 5; % mT

ExpSpectrum.Field = 324.9; % mT

pepper(Sys,ExpSpectrum);

% Pulse definitions
Pulse90.tp = 0.020; % s
Pulse90.Frequency = 0; % MHz

Pulse180 = Pulse90;

Pulse90.Flip = pi/2; % radians
Pulse180.Flip = pi; % radians

% Experiment definition (two-pulse echo)
tau = 0.5; % s
Exp.Sequence = {Pulse90 tau Pulse180 tau+Pulse90.tp/2};

Exp.mwFreq = 9.12; % GHz
Exp.Field = 324.9; % mT
Exp.DetWindow = [-0.03 0.03]; % s

Opt.nKnots = 20; % Powder average!

[t,Signal] = saffron(Sys,Exp,Opt);

plot(t,Signal)
xlabel('t (s)')
ylabel('Signal (arb.u.)')

%% EXERCISE 15-03: saffron, two-pulse echo with monochromatic rectangular pulses
%{
Use the example from above to create your own echo sequence
using the two WURST pulses that we previously designed. You might want to
center you pulses around the center of the nitroxide spectrum (9.1 GHz at
324.9 mT). Then plot the absolute value of the signal.
%}

clear Sequence Exp

Exp.Field = 324.9; % mT
tau = 0.5; % s

Exp.Sequence = {WURST{1} tau WURST{2} tau+WURST{2}.tp};

Exp.mwFreq = 9.1; % GHz
Exp.Field = 324.9; % mT
Exp.DetWindow = [-0.03 0.03]; % s

[t, Signal] = saffron(Sys,Exp,Opt);

plot(t,abs(Signal))
xlabel('t (s)')
ylabel('Signal (arb.u.)')


%% DEMONSTRATION 15-04: spidyan, working with detection operators
%{
With spidyan it is possible to take a closer look at how individual
spin packets evolve during a pulse or an entire sequence. In contrast to
saffron it is possible to define (not necessarily physical) detection
operators that can be used to observe even during pulses. Here, we have a
look at what happens to a single S = 1/2 spin during the above pi
pulse.
%}
clear; close; clc;

% Spin system
Sys.ZeemanFreq = 9.150; % resonance frequency of spin packet in GHz

% Pulse definition
WURST.Type = 'WURST/linear'; 
WURST.tp = 0.100; % s
WURST.Frequency = [150 -150]; % MHz
WURST.nwurst = 8;
WURST.Flip = pi; % radians

% Experiment/sequence
Exp.Sequence = {WURST};
Exp.mwFreq = 9.100; % GHz

% Detection
Exp.DetOperator = {'z1','+1'}; % detection operators
Exp.DetFreq = [0 9.1]; % downconversion frequencies in GHz

[t,Signal] = spidyan(Sys,Exp);

% Plotting
figure(1)
clf
plot(t*1000,real(Signal));
xlabel('t (ns)')
axis tight
ylim([-1 1])
ylabel('<S_i>')
legend(Exp.DetOperator)

%% EXERCISE 15-04: spidyan, adiabatic passage and the Bloch sphere
%{
Plot the trajectory of the spin packet during the above WURST pulse on a
Bloch sphere (tip: use plot3(...) to create a 3D plot). What happens if
you change the resonance frequency of the spin packet by 50 MHz?
%}

figure(2)
clf
plot3(real(Signal(:,2)),imag(Signal(:,2)),real(Signal(:,1)));
grid on
xlabel('<S_x>')
ylabel('<S_y>')
zlabel('<S_z>')
axis equal
