%% EasySpin Academy 2020 - Session 16 - Varia
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%{
This session discusses topics that were suggested by the audience on day 2.
%}

%% DEMONSTRATION 16-01: ORCA interface
%{
ORCA: a quantum chemistry program well suited for calculating EPR parameters
of paramagnetic centers. EasySpin can directly import ORCA calculation
results. Besides the text output file, ORCA generates a binary .prop file.
This file contains the calculated properties that are read in by EasySpin.
%}

% Show ORCA input file hydroxyl_gA.oif
% Show ORCA output file hydroxyl_gA.oof

clear, clc

% Load the results for a hydroxyl radical from property file
Sys = orca2easyspin('hydroxyl_gA'); % assumes .prop file extension

% Sys contains the xyz coordinates, the atomic numbers, and the
% calculated spin parameters
Sys

% Assume we have this radical trapped in a solid matrix:
% Simulate solid-state powder spectrum
Sys.lwpp = 0.2;
Exp.mwFreq = 9.5;
Opt.Output = 'separate';
pepper(Sys,Exp,Opt);


%% DEMONSTRATION 16-02: Magnetometry

% curry calculates SQUID data: susceptibility etc.
% 
clear, clf, clc

% Define the spin system and experimental parameters for curry
Sys.S = 1/2;
Sys.g = 2;

B = 5000; % mT;
T = 2:0.5:100; % K
Exp.Field = B; % mT
Exp.Temperature = T; % K

% Without outputs, curry plots several magnetometry quantitites
curry(Sys,Exp);

% SI vs CGS units - compare in two figures
figure
Opt.Units = 'cgs';
curry(Sys,Exp,Opt);

% Let's compare the temp. dependence of the molar magnetic susceptibility
% to the Curie law

% Ask curry to return molar magnetic susceptibility
Opt.Units = 'SI';
Opt.Output = 'chimol';
chimol = curry(Sys,Exp,Opt);
% show reference page with other quantities

chimol_Curie = mu0*avogadro*bmagn^2*...
  Sys.g^2*Sys.S*(Sys.S+1)/3/boltzm./Exp.Temperature;  % SI units

% Plot the result. You can see that at low temperatures the Curie
% law is an invalid approximation to the correct susceptibility.
clf

% as a function of T
subplot(2,1,1)
plot(T,chimol,T,chimol_Curie);
legend('exact','Curie law');

% as a function of 1/T
subplot(2,1,2)
plot(1./T,chimol,1./T,chimol_Curie);


%% DEMONSTRATION 16-03: Magnetometry

% Two coupled spins-1/2
% Example shows how to handle exchange coupling definition

clear, clf, clc

% Define the two-spin system
Sys.S = [1/2 1/2];
Sys.g = [2 2];

% Here is a J value, given for -2*J12*S1*S2, and in units of cm^-1
J12 = 30;   % cm^-1, H = -2*J12*S1*S2

% First, we convert units to the required MHz
J12 = J12*100*clight/1e6; % cm^-1 -> MHz

% Then, we set the exchange coupling. Since EasySpin defines the
% exchange operator as H = J*S1*S2, we set J = -2*J12.
Sys.J = -2*J12;

% Define the experimental parameters: field and temperature
Exp.Field = linspace(0,8,50)*1000;   % mT
Exp.Temperature = 4;   % K

% Call curry and plot the result
[muz,chizz] = curry(Sys,Exp);

% Plot the results
B = Exp.Field/1e3;    % mT -> T

subplot(1,2,1);
plot(B,muz);
xlabel('magnetic field (T)');
ylabel('magnetic moment (\mu_B)');

subplot(1,2,2);
plot(B,chizz);
xlabel('magnetic field (T)');
ylabel('molar magnetic susceptibility (m^3 mol^{-1})');
